@@ -49,7 +49,7 @@ def model_dict_to_str(
         type_cast_str = edgedb_conversion_map.get(field_name, {}).get("cast")
         if not type_cast_str:
             # resolvers will come up here so ignore them
-            if field_name in set_links_d or val == set():
+            if (set_links_d and field_name in set_links_d) or val == set():
                 continue
             raise NodeException(f"{field_name=} not in {edgedb_conversion_map=}")
         variable_name = f"{field_name}{random_str(10)}"
