@@ -402,12 +402,12 @@ class Resolver(BaseModel, T.Generic[NodeType]):
             raise ResolverException(f"Field '{key}' is not exclusive.")
         # this is to avoid nested collisions
         variables = {key: value}
-        if type(value) is UUID or key == "id":
+        if isinstance(value, UUID) or key == "id":
             value_str = f"<uuid>${key}"
-        elif type(value) is str or isinstance(value, Enum):
+        elif isinstance(value, str) or isinstance(value, Enum):
             # assume it is a string, can add if int or datetime i guess...
             value_str = f"<str>${key}"
-        elif type(value) is int:
+        elif isinstance(value, int):
             value_str = f"<int16>${key}"
         else:
             value_str = value
